@@ -244,6 +244,7 @@ struct de265_image {
   }
 
   void fill_image(int y,int u,int v);
+  void fill_plane(int channel, int value);
   de265_error copy_image(const de265_image* src);
   void copy_lines_from(const de265_image* src, int first, int end);
   void exchange_pixel_data_with(de265_image&);
@@ -428,7 +429,7 @@ public:
                                      void* userdata);
   */
 
-  uint8_t integrity; /* Whether an error occured while the image was decoded.
+  uint8_t integrity; /* Whether an error occurred while the image was decoded.
                         When generated, this is initialized to INTEGRITY_CORRECT,
                         and changed on decoding errors.
                       */
@@ -624,7 +625,14 @@ public:
 
   enum IntraPredMode get_IntraPredMode(int x,int y) const
   {
-    return (enum IntraPredMode)intraPredMode.get(x,y);
+    uint8_t ipm = intraPredMode.get(x,y);
+
+    // sanitize values if IPM is uninitialized (because of earlier read error)
+    if (ipm > 34) {
+      ipm = 0;
+    }
+
+    return static_cast<enum IntraPredMode>(ipm);
   }
 
   enum IntraPredMode get_IntraPredMode_atIndex(int idx) const
