@@ -147,6 +147,9 @@ void decode_quantization_parameters(thread_context* tctx, int xC,int yC,
              (52 + sps.QpBdOffset_Y)) - sps.QpBdOffset_Y;
 
   tctx->qPYPrime = QPY + sps.QpBdOffset_Y;
+  if (tctx->qPYPrime<0) {
+    tctx->qPYPrime=0;
+  }
 
   int qPiCb = Clip3(-sps.QpBdOffset_C,57, QPY+pps.pic_cb_qp_offset + shdr->slice_cb_qp_offset + tctx->CuQpOffsetCb);
   int qPiCr = Clip3(-sps.QpBdOffset_C,57, QPY+pps.pic_cr_qp_offset + shdr->slice_cr_qp_offset + tctx->CuQpOffsetCr);
@@ -169,7 +172,14 @@ void decode_quantization_parameters(thread_context* tctx, int xC,int yC,
   //printf("q: %d %d\n",qPiCb, qPCb);
 
   tctx->qPCbPrime = qPCb + sps.QpBdOffset_C;
+  if (tctx->qPCbPrime<0) {
+    tctx->qPCbPrime = 0;
+  }
+
   tctx->qPCrPrime = qPCr + sps.QpBdOffset_C;
+  if (tctx->qPCrPrime<0) {
+    tctx->qPCrPrime = 0;
+  }
 
   /*
   printf("Q: %d (%d %d %d / %d %d) %d %d %d\n",QPY,
@@ -479,6 +489,11 @@ void scale_coefficients_internal(thread_context* tctx,
 
       const uint8_t* sclist;
       int matrixID = cIdx;
+
+      if (nT==32) {
+        matrixID=0;
+      }
+
       if (!intra) {
         if (nT<32) { matrixID += 3; }
         else { matrixID++; }
@@ -494,10 +509,8 @@ void scale_coefficients_internal(thread_context* tctx,
 
       for (int i=0;i<tctx->nCoeff[cIdx];i++) {
         int pos = tctx->coeffPos[cIdx][i];
-        int x = pos%nT;
-        int y = pos/nT;
 
-        const int m_x_y = sclist[x+y*nT];
+        const int m_x_y = sclist[pos];
         const int fact = m_x_y * levelScale[qP%6] << (qP/6);
 
         int64_t currCoeff  = tctx->coeffList[cIdx][i];
@@ -645,7 +658,7 @@ void scale_coefficients(thread_context* tctx,
 
 //#define QUANT_IQUANT_SHIFT    20 // Q(QP%6) * IQ(QP%6) = 2^20
 #define QUANT_SHIFT           14 // Q(4) = 2^14
-//#define SCALE_BITS            15 // Inherited from TMuC, pressumably for fractional bit estimates in RDOQ
+//#define SCALE_BITS            15 // Inherited from TMuC, presumably for fractional bit estimates in RDOQ
 #define MAX_TR_DYNAMIC_RANGE  15 // Maximum transform dynamic range (excluding sign bit)
 
 
